@@ -51,12 +51,22 @@ void main_ui_enable(appdata_t *appdata) {
     gtk_window_set_title(GTK_WINDOW(appdata->window), "");
 #else
   char *str = NULL;
+#ifdef USE_HILDON
   if(project_valid) 
-    str = g_strdup_printf("OSM2Go - %s", appdata->project->name);
+    str = g_markup_printf_escaped("OSM2Go - <b>%s</b>", 
+				  appdata->project->name);
+  else 
+    str = g_markup_printf_escaped("OSM2Go");
+
+  hildon_window_set_markup(HILDON_WINDOW(appdata->window), str);
+#else
+  if(project_valid) 
+    str = g_strdup_printf("OSM2Go - <b>%s</b>", appdata->project->name);
   else 
     str = g_strdup_printf("OSM2Go");
-    
+
   gtk_window_set_title(GTK_WINDOW(appdata->window), str);
+#endif
   g_free(str);
 #endif
 
@@ -1221,10 +1231,14 @@ int main(int argc, char *argv[]) {
   g_set_application_name("OSM2Go");
   
   /* Create HildonWindow and set it to HildonProgram */
+#if MAEMO_VERSION_MAJOR < 5
   appdata.window = HILDON_WINDOW(hildon_window_new());
+#else
+  appdata.window = HILDON_WINDOW(hildon_stackable_window_new());
+#endif
   hildon_program_add_window(appdata.program, appdata.window);
 
-#if MAEMO_VERSION_MAJOR == 5
+#if MAEMO_VERSION_MAJOR == 6
   unsigned long val;
   XChangeProperty(GDK_DISPLAY(),
 		  GDK_WINDOW_XID(GTK_WIDGET(appdata.window)->window),
@@ -1276,38 +1290,29 @@ int main(int argc, char *argv[]) {
     return -1;
   }
 
-#if 0  // another test overlay
-  {
-    GtkWidget *fixed = gtk_fixed_new();
-
-    gtk_fixed_put(GTK_FIXED(fixed), gtk_label_new("Nase"), 0,0);
-    gtk_fixed_put(GTK_FIXED(fixed), map, 0,0);
-
-    gtk_box_pack_start(GTK_BOX(vbox), fixed, TRUE, TRUE, 0);
-  }
-#else
   gtk_box_pack_start(GTK_BOX(vbox), map, TRUE, TRUE, 0);
-#endif
 
 #ifdef ZOOM_BUTTONS  
   GtkWidget *zhbox = gtk_hbox_new(FALSE, 0);
 
   gtk_box_pack_start_defaults(GTK_BOX(zhbox), statusbar_new(&appdata));
 
-  /* ---- add zoom in button right of statusbar ---- */
-  appdata.btn_zoom_in = gtk_button_new();
-  gtk_button_set_image(GTK_BUTTON(appdata.btn_zoom_in), 
-		       gtk_image_new_from_stock(GTK_STOCK_ZOOM_IN, GTK_ICON_SIZE_MENU));
-  g_signal_connect(appdata.btn_zoom_in, "clicked", G_CALLBACK(cb_menu_zoomin), &appdata);
-  gtk_box_pack_start(GTK_BOX(zhbox), appdata.btn_zoom_in, FALSE, FALSE, 0);
-
   /* ---- add zoom out button right of statusbar ---- */
   appdata.btn_zoom_out = gtk_button_new();
   gtk_button_set_image(GTK_BUTTON(appdata.btn_zoom_out), 
-		       gtk_image_new_from_stock(GTK_STOCK_ZOOM_OUT, GTK_ICON_SIZE_MENU));
-  g_signal_connect(appdata.btn_zoom_out, "clicked", G_CALLBACK(cb_menu_zoomout), &appdata);
+	gtk_image_new_from_stock(GTK_STOCK_ZOOM_OUT, GTK_ICON_SIZE_MENU));
+  g_signal_connect(appdata.btn_zoom_out, "clicked", 
+		   G_CALLBACK(cb_menu_zoomout), &appdata);
   gtk_box_pack_start(GTK_BOX(zhbox), appdata.btn_zoom_out, FALSE, FALSE, 0);
 
+  /* ---- add zoom in button right of statusbar ---- */
+  appdata.btn_zoom_in = gtk_button_new();
+  gtk_button_set_image(GTK_BUTTON(appdata.btn_zoom_in), 
+	gtk_image_new_from_stock(GTK_STOCK_ZOOM_IN, GTK_ICON_SIZE_MENU));
+  g_signal_connect(appdata.btn_zoom_in, "clicked", 
+		   G_CALLBACK(cb_menu_zoomin), &appdata);
+  gtk_box_pack_start(GTK_BOX(zhbox), appdata.btn_zoom_in, FALSE, FALSE, 0);
+
 
   gtk_box_pack_start(GTK_BOX(vbox), zhbox, FALSE, FALSE, 0);
 #else
@@ -1354,6 +1359,13 @@ int main(int argc, char *argv[]) {
     gtk_window_set_keep_above(GTK_WINDOW(overlay), TRUE);    
     gtk_window_set_destroy_with_parent(GTK_WINDOW(overlay), TRUE);
     gtk_window_set_position(GTK_WINDOW(overlay), GTK_WIN_POS_CENTER_ON_PARENT);
+
+    gtk_window_set_gravity(GTK_WINDOW(overlay), GDK_GRAVITY_NORTH_EAST);
+
+    printf("x = %d\n", gdk_screen_width() - overlay->allocation.width);
+    gtk_window_move(GTK_WINDOW(overlay), 
+		    gdk_screen_width() - overlay->allocation.width, 60);
+
     gtk_window_set_decorated(GTK_WINDOW(overlay), TRUE);
 
     /* add some zoom buttons for testing */
