@@ -37,7 +37,6 @@
 #undef SERVER_EDITABLE
 
 typedef struct {
-  appdata_t *appdata;
   project_t *project;
   settings_t *settings;
   GtkWidget *dialog, *fsize, *diff_stat, *diff_remove;
@@ -105,6 +104,7 @@ static gboolean project_read(appdata_t *appdata,
 	      
 	    } else if(project->map_state && 
 		      strcasecmp((char*)node->name, "map") == 0) {
+
 	      if((str = (char*)xmlGetProp(node, BAD_CAST "zoom"))) {
 		project->map_state->zoom = g_ascii_strtod(str, NULL);
 		xmlFree(str);
@@ -185,7 +185,7 @@ static gboolean project_read(appdata_t *appdata,
       }
     }
   }
-  
+
   xmlFreeDoc(doc);
   xmlCleanupParser();
 
@@ -874,7 +874,7 @@ void project_filesize(project_context_t *context) {
     str = g_strdup(_("Not downloaded!"));
 
     gtk_dialog_set_response_sensitive(GTK_DIALOG(context->dialog), 
-				      GTK_RESPONSE_ACCEPT, FALSE);
+				      GTK_RESPONSE_ACCEPT, !context->is_new);
 
   } else {
     gtk_widget_modify_fg(context->fsize, GTK_STATE_NORMAL, NULL);
@@ -887,7 +887,8 @@ void project_filesize(project_context_t *context) {
       str = g_strdup_printf(_("Outdated, please download!"));
 
     gtk_dialog_set_response_sensitive(GTK_DIALOG(context->dialog), 
-		      GTK_RESPONSE_ACCEPT, !context->project->data_dirty);
+		      GTK_RESPONSE_ACCEPT, !context->is_new ||
+				      !context->project->data_dirty);
   }
 
   if(str) {
@@ -946,7 +947,7 @@ static void on_edit_clicked(GtkButton *button, gpointer data) {
 
     /* (re-) download area */
     if(osm_download(GTK_WIDGET(context->dialog), 
-		    context->appdata->settings, context->project))
+	    context->area_edit.appdata->settings, context->project))
        context->project->data_dirty = FALSE;
     
     project_filesize(context);
@@ -1017,19 +1018,15 @@ project_edit(appdata_t *appdata, GtkWidget *parent, settings_t *settings,
     return ok;
 
   /* ------------ project edit dialog ------------- */
-  
+
   project_context_t *context = g_new0(project_context_t, 1);
-  context->appdata = appdata;
   context->project = project;
   context->area_edit.settings = context->settings = settings;
+  context->area_edit.appdata = appdata;
   context->is_new = is_new;
   
   context->area_edit.min = &project->min;
   context->area_edit.max = &project->max;
-#ifdef USE_HILDON
-  context->area_edit.mmpos = &appdata->mmpos;
-  context->area_edit.osso_context = appdata->osso_context;
-#endif
 
   /* cancel is enabled for "new" projects only */
   if(is_new) {
